--- title: "wallaroo.datasizeunit" type: docs linkTitle: "wallaroo.datasizeunit" ---
class DataSizeUnit(enum.Enum):

Data size limits for exported pipeline log files

KiB = <DataSizeUnit.KiB: 'KiB'>
MiB = <DataSizeUnit.MiB: 'MiB'>
GiB = <DataSizeUnit.GiB: 'GiB'>
TiB = <DataSizeUnit.TiB: 'TiB'>
@staticmethod
def from_string(unit_str):
def calculate_bytes(self, size):

##### Inherited Members

enum.Enum
  name
  value